@@ -5,7 +5,7 @@ from datetime import datetime
 
 class Api():
     """Api class
-    
+
     This class is used to get data from nhentai api.
 
     Attributes:
@@ -15,24 +15,43 @@ class Api():
         hentaifox (str): The base url of hentaifox api.
         hentai2read (str): The base url of hentai2read api.
     """
-    with open('Base.json', 'r', encoding='utf-8') as f:
-        nh = json.load(f)
 
     def __init__(self,
-                 BASE_URL: str = nh['nhentai']['api'],
-                 BASE_IMG: str = nh['nhentai']['img'],
-                 BASE_PURURIN: str = nh['pururin']['api'],
-                 BASE_HENTAIFOX: str = nh['hentaifox']['api'],
-                 BASE_HENTAI2READ: str = nh['hentai2read']['api']):
+                 BASE_URL: str = "https://nhentai.net",
+                 BASE_IMG: str = "https://i.nhentai.net/galleries",
+                 BASE_PURURIN: str = "https://scathach.redsplit.org/v4/pururin/",
+                 BASE_NHENTAI_UNBLOCK: str = "https://nhentai.sinxdr.workers.dev",
+                 BASE_HENTAIFOX: str = "https://scathach.redsplit.org/v4/hentaifox/",
+                 BASE_HENTAI2READ: str = "https://scathach.redsplit.org/v4/hentai2read/"):
 
         self.api = BASE_URL
         self.img = BASE_IMG
         self.pururin = BASE_PURURIN
         self.hentaifox = BASE_HENTAIFOX
         self.hentai2read = BASE_HENTAI2READ
+        self.nhentai_unblock = BASE_NHENTAI_UNBLOCK
+
 
 BASE_URL = Api()
 
+
+def list_api():
+    """Returns the api url.
+
+    Returns
+    -------
+    list
+    """
+    # create list of api
+    api_list = [
+        BASE_URL.api,
+        BASE_URL.pururin,
+        BASE_URL.hentaifox,
+        BASE_URL.hentai2read
+    ]
+    return api_list
+
+
 def auto_space(string: str):
     """Automatically adds spaces for GET requests
 
